@@ -204,10 +204,8 @@ def extract_by_var(vars, state_codes,
     export_tmp_state_fp = path + '/us_census_api_extract_state.parquet.gzip'
 
     # Split df into batches smaller than 45 (50 - 5) to satisfy API Query limits
-    # vars = np.array_split(vars, 450)
-    print(len(vars))
     vars = np.array_split(vars, math.ceil(len(vars)/45))
-    print(vars)
+
     # In case the process gets interupted, start processing from last
     # index processed.
     states_processed = progress.get_int('states_processed')
